pub type Pointer<T> = Pointer<T>;Expand description
A raw pointer that can be used in a runtime interface function signature.
Aliased Type
pub struct Pointer<T> { /* private fields */ }Trait Implementations
Sourceimpl<'a, T: PointerType> FromFFIValue<'a> for Pointer<T>
Available on non-substrate_runtime only.
impl<'a, T: PointerType> FromFFIValue<'a> for Pointer<T>
Available on non-
substrate_runtime only.Sourcefn from_ffi_value(_: &mut dyn FunctionContext, arg: u32) -> Result<Self>
fn from_ffi_value(_: &mut dyn FunctionContext, arg: u32) -> Result<Self>
Creates
Self::Owned from the given arg received through the FFI boundary from the
runtime.Sourcefn take_from_owned(owned: &'a mut Self::Owned) -> Self::Inner
fn take_from_owned(owned: &'a mut Self::Owned) -> Self::Inner
Creates
Self::Inner from an owned value.Sourceimpl<T: PointerType> IntoFFIValue for Pointer<T>
Available on non-substrate_runtime only.
impl<T: PointerType> IntoFFIValue for Pointer<T>
Available on non-
substrate_runtime only.Sourcefn into_ffi_value(value: Self, _: &mut dyn FunctionContext) -> Result<u32>
fn into_ffi_value(value: Self, _: &mut dyn FunctionContext) -> Result<u32>
Convert
Self::Inner into an FFI value.